@@ -36,6 +36,7 @@
 
 from __future__ import annotations
 
+import copy
 from typing import Optional
 
 import numpy as np
@@ -45,6 +46,8 @@ from phonopy.file_IO import parse_disp_yaml, write_FORCE_SETS
 from phonopy.interface.calculator import get_calc_dataset, get_calc_dataset_wien2k
 from phonopy.interface.lammps import rotate_lammps_forces
 from phonopy.interface.phonopy_yaml import PhonopyYaml
+from phonopy.structure.atoms import PhonopyAtoms
+from phonopy.structure.dataset import get_displacements_and_forces
 
 
 def create_FORCE_SETS(
@@ -66,8 +69,8 @@ def create_FORCE_SETS(
     """
     if log_level > 0:
         if interface_mode:
-            print("Calculator interface: %s" % interface_mode)
-        print('Displacements were read from "%s".' % disp_filename)
+            print(f"Calculator interface: {interface_mode}")
+        print(f'Displacements were read from "{disp_filename}".')
         if disp_filename == "disp.yaml":
             print("")
             print("NOTE:")
@@ -83,8 +86,8 @@ def create_FORCE_SETS(
             print("")
         if force_sets_zero_mode:
             print(
-                "Forces in %s are subtracted from forces in all "
-                "other files." % force_filenames[0]
+                f'Forces in "{force_filenames[0]}" are subtracted from forces in all '
+                "other files."
             )
 
     if disp_filename == "disp.yaml":
@@ -112,31 +115,64 @@ def create_FORCE_SETS(
         raise RuntimeError(
             "Number of atoms could not be retrieved from %s" % disp_filename
         )
-    if force_sets_zero_mode:
-        num_displacements += 1
 
-    if not check_number_of_force_files(
-        num_displacements, force_filenames, disp_filename
+    if log_level > 0:
+        print(f"  Number of supercell files: {len(force_filenames)}")
+        print(f'  Number of displacements in "{disp_filename}": {num_displacements}')
+
+    if "first_atoms" in disp_dataset and not check_number_of_force_files(
+        num_displacements,
+        force_filenames,
+        disp_filename,
+        force_sets_zero_mode=force_sets_zero_mode,
     ):
         force_sets = []
-    elif interface_mode == "wien2k":
-        calc_dataset = get_calc_dataset_wien2k(
-            force_filenames,
-            supercell,
-            disp_dataset,
-            wien2k_P1_mode=wien2k_P1_mode,
-            symmetry_tolerance=symmetry_tolerance,
-            verbose=(log_level > 0),
-        )
-        force_sets = calc_dataset["forces"]
     else:
-        calc_dataset = get_calc_dataset(
-            interface_mode,
-            num_atoms,
-            force_filenames,
-            verbose=(log_level > 0),
-        )
-        force_sets = calc_dataset["forces"]
+        if interface_mode == "wien2k":
+            calc_dataset = get_calc_dataset_wien2k(
+                force_filenames,
+                supercell,
+                disp_dataset,
+                wien2k_P1_mode=wien2k_P1_mode,
+                symmetry_tolerance=symmetry_tolerance,
+                verbose=(log_level > 0),
+            )
+            force_sets = calc_dataset["forces"]
+        else:
+            calc_dataset = get_calc_dataset(
+                interface_mode,
+                num_atoms,
+                force_filenames,
+                verbose=(log_level > 0),
+            )
+            force_sets = calc_dataset["forces"]
+            if "points" in calc_dataset:
+                if force_sets_zero_mode:
+                    range_start = 1
+                else:
+                    range_start = 0
+                if filename := check_agreements_of_displacements(
+                    supercell,
+                    disp_dataset,
+                    calc_dataset["points"][range_start:],
+                    force_filenames[range_start:],
+                ):
+                    raise RuntimeError(
+                        "Displacements don't match with atomic positions in "
+                        f'"{filename}".'
+                    )
+                if force_sets_zero_mode:
+                    if check_agreement_of_supercell_positions(
+                        supercell, calc_dataset["points"][0]
+                    ):
+                        raise RuntimeError(
+                            "Supercell doesn't match with atomic positions in "
+                            f'"{force_filenames[0]}".'
+                        )
+
+    if log_level > 0 and "first_atoms" not in disp_dataset:
+        if len(force_filenames) < num_displacements:
+            print("** Number of supercell files is less than displacements. **")
 
     if interface_mode == "lammps":
         rotate_lammps_forces(force_sets, supercell.cell, verbose=(log_level > 0))
@@ -144,24 +180,25 @@ def create_FORCE_SETS(
     if force_sets:
         if force_sets_zero_mode:
             force_sets = _subtract_residual_forces(force_sets)
-        if dataset_type == 1:
-            for forces, disp in zip(force_sets, disp_dataset["first_atoms"]):
-                disp["forces"] = forces
-        elif dataset_type == 2:
-            disp_dataset["forces"] = np.array(force_sets, dtype="double", order="C")
-        else:
-            raise RuntimeError("Force sets could not be found.")
+        energies = calc_dataset.get("supercell_energies")
 
-        if "supercell_energies" in calc_dataset:
-            energies = np.array(calc_dataset["supercell_energies"], dtype="double")
-            if dataset_type == 1:
-                for energy, disp in zip(energies, disp_dataset["first_atoms"]):
+        if dataset_type == 1:
+            dataset = copy.deepcopy(disp_dataset)
+            for forces, disp in zip(force_sets, dataset["first_atoms"]):
+                disp["forces"] = forces
+            if energies is not None:
+                for energy, disp in zip(energies, dataset["first_atoms"]):
                     disp["supercell_energy"] = energy
-            elif dataset_type == 2:
-                disp_dataset["supercell_energies"] = energies
+        elif dataset_type == 2:
+            dataset = {
+                "displacements": disp_dataset["displacements"][: len(force_sets)],
+                "forces": force_sets,
+            }
+            if energies is not None:
+                dataset["supercell_energies"] = energies
 
         if save_params:
-            phpy_yaml.dataset = disp_dataset
+            phpy_yaml.dataset = dataset
             nac_params = get_nac_params(primitive=phpy_yaml.primitive)
             if nac_params:
                 phpy_yaml.nac_params = nac_params
@@ -171,7 +208,7 @@ def create_FORCE_SETS(
             if log_level > 0:
                 print(f'"{yaml_filename}" has been created.')
         else:
-            write_FORCE_SETS(disp_dataset, filename=force_sets_filename)
+            write_FORCE_SETS(dataset, filename=force_sets_filename)
             if log_level > 0:
                 print(f'"{force_sets_filename}" has been created.')
 
@@ -180,24 +217,55 @@ def create_FORCE_SETS(
             print("%s could not be created." % force_sets_filename)
 
 
-def check_number_of_force_files(num_displacements, force_filenames, disp_filename):
+def check_number_of_force_files(
+    num_displacements, force_filenames, disp_filename, force_sets_zero_mode=False
+):
     """Verify number of supercell force files.
 
     This function is public because being used from phono3py.
 
     """
-    if num_displacements != len(force_filenames):
-        print("")
-        print("Number of files to be read (%d) don't match to" % len(force_filenames))
+    if force_sets_zero_mode:
+        num_force_filenames = len(force_filenames) - 1
+    else:
+        num_force_filenames = len(force_filenames)
+
+    if num_displacements != num_force_filenames:
+        print(f"Number of files to be read ({num_force_filenames}) don't match to")
         print(
-            "the number of displacements (%d) in %s."
-            % (num_displacements, disp_filename)
+            f'the number of displacements ({num_displacements}) in "{disp_filename}".'
         )
         return False
     else:
         return True
 
 
+def check_agreements_of_displacements(
+    supercell: PhonopyAtoms,
+    dataset: dict,
+    all_points: list[np.ndarray],
+    force_filenames: list[str],
+) -> Optional[str]:
+    """Check agreements of displacements."""
+    displacements = get_displacements_and_forces(dataset)[0] @ np.linalg.inv(
+        supercell.cell
+    )
+    for disp, points, filename in zip(displacements, all_points, force_filenames):
+        diff = supercell.scaled_positions + disp - points
+        diff -= np.rint(diff)
+        if (np.linalg.norm(diff @ supercell.cell, axis=1) > 1e-5).any():
+            return filename
+
+
+def check_agreement_of_supercell_positions(
+    supercell: PhonopyAtoms, points: np.ndarray
+) -> bool:
+    """Check agreement of supercell positions."""
+    diff = supercell.scaled_positions - points
+    diff -= np.rint(diff)
+    return (np.linalg.norm(diff @ supercell.cell, axis=1) > 1e-5).any()
+
+
 def _subtract_residual_forces(force_sets):
     for i in range(1, len(force_sets)):
         force_sets[i] -= force_sets[0]
