@@ -280,12 +280,12 @@ def select_and_extract_force_constants(
             _force_constants_filename = "force_constants.hdf5"
 
     if _fc is not None:
+        if log_level and _force_constants_filename is not None:
+            print(f'Force constants were read from "{_force_constants_filename}".')
         if not is_compact_fc and _fc.shape[0] != _fc.shape[1]:
             _fc = compact_fc_to_full_fc(phonon.primitive, _fc, log_level=log_level)
         elif is_compact_fc and _fc.shape[0] == _fc.shape[1]:
             _fc = full_fc_to_compact_fc(phonon.primitive, _fc, log_level=log_level)
-        if log_level and _force_constants_filename is not None:
-            print(f'Force constants were read from "{_force_constants_filename}".')
 
     return _fc
 
@@ -346,7 +346,6 @@ def check_nac_params(nac_params: dict, unitcell: PhonopyAtoms, pmat: np.ndarray)
 def _run_pypolymlp(
     phonon: Phonopy,
     mlp_params: Union[str, dict, PypolymlpParams],
-    mlp_filename: str = "phonopy.pmlp",
     log_level: int = 0,
 ):
     """Run pypolymlp to compute forces."""
@@ -361,22 +360,39 @@ def _run_pypolymlp(
                 if v is not None:
                     print(f"  {k}: {v}")
 
-    _mlp_filename_list = list(pathlib.Path().glob(f"{mlp_filename}*"))
-    if _mlp_filename_list:
-        _mlp_filename = _mlp_filename_list[0]
-        if log_level:
-            print(f'Load MLPs from "{_mlp_filename}".')
-        phonon.load_mlp(_mlp_filename)
-        phonon.mlp_dataset = None
-    elif forces_in_dataset(phonon.mlp_dataset):
-        if log_level:
-            print("Developing MLPs by pypolymlp...", flush=True)
-        phonon.develop_mlp(params=mlp_params)
-        phonon.save_mlp(filename=mlp_filename)
-        if log_level:
-            print(f'MLPs were written into "{mlp_filename}"', flush=True)
-    else:
-        raise RuntimeError(f'"{mlp_filename}" is not found.')
+    mlp_loaded = False
+    for mlp_filename in ["polymlp.yaml", "phonopy.pmlp"]:
+        _mlp_filename_list = list(pathlib.Path().glob(f"{mlp_filename}*"))
+        if _mlp_filename_list:
+            _mlp_filename = _mlp_filename_list[0]
+            if _mlp_filename.suffix not in [
+                ".yaml",
+                ".pmlp",
+                ".xz",
+                ".gz",
+                ".bz2",
+                "lzma",
+            ]:
+                continue
+            if log_level:
+                print(f'Load MLPs from "{_mlp_filename}".')
+            phonon.load_mlp(_mlp_filename)
+            mlp_loaded = True
+            if log_level and mlp_filename == "phonopy.pmlp":
+                print(f'Loading MLPs from "{_mlp_filename}" is obsolete.')
+            break
+
+    mlp_filename = "polymlp.yaml"
+    if not mlp_loaded:
+        if forces_in_dataset(phonon.mlp_dataset):
+            if log_level:
+                print("Developing MLPs by pypolymlp...", flush=True)
+            phonon.develop_mlp(params=mlp_params)
+            phonon.save_mlp()
+            if log_level:
+                print(f'MLPs were written into "{mlp_filename}"', flush=True)
+        else:
+            raise RuntimeError(f'"{mlp_filename}" is not found.')
 
     if log_level:
         print("-" * 30 + " pypolymlp end " + "-" * 31, flush=True)
@@ -447,11 +463,6 @@ def _read_force_constants_file(
     else:
         _fc = parse_FORCE_CONSTANTS(filename=force_constants_filename, p2s_map=p2s_map)
 
-    if is_compact_fc and _fc.shape[0] == _fc.shape[1]:
-        _fc = full_fc_to_compact_fc(phonon.primitive, _fc, log_level=log_level)
-    elif not is_compact_fc and _fc.shape[0] != _fc.shape[1]:
-        _fc = compact_fc_to_full_fc(phonon.primitive, _fc, log_level=log_level)
-
     return _fc
 
 
