@@ -63,8 +63,10 @@ class Settings:
         "band_points": None,
         "cell_filename": None,
         "chemical_symbols": None,
+        "classical": False,
         "cutoff_frequency": None,
         "displacement_distance": None,
+        "displacement_distance_max": None,
         "dm_decimals": None,
         "calculator": None,
         "create_displacements": False,
@@ -146,6 +148,10 @@ class Settings:
         """Set chemical_symbols."""
         self._v["chemical_symbols"] = val
 
+    def set_classical(self, val):
+        """Set classical."""
+        self._v["classical"] = val
+
     def set_create_displacements(self, val):
         """Set create_displacements."""
         self._v["create_displacements"] = val
@@ -162,6 +168,10 @@ class Settings:
         """Set displacement_distance."""
         self._v["displacement_distance"] = val
 
+    def set_displacement_distance_max(self, val):
+        """Set displacement_distance_max."""
+        self._v["displacement_distance_max"] = val
+
     def set_calculator(self, val):
         """Set calculator."""
         self._v["calculator"] = val
@@ -355,7 +365,7 @@ class ConfParser:
     def get_configures(self):
         """Return configuration dict."""
         warnings.warn(
-            "ConfParser.get_configures() is deprecated." "Use confs attribute.",
+            "ConfParser.get_configures() is deprecated.Use confs attribute.",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -369,7 +379,7 @@ class ConfParser:
     def get_settings(self):
         """Return Settings class instance."""
         warnings.warn(
-            "ConfParser.get_settings() is deprecated." "Use settings attribute.",
+            "ConfParser.get_settings() is deprecated.Use settings attribute.",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -439,14 +449,24 @@ class ConfParser:
             if self._args.cell_filename is not None:
                 self._confs["cell_filename"] = self._args.cell_filename
 
+        if "classical" in arg_list:
+            if self._args.classical:
+                self._confs["classical"] = ".true."
+
         if "cutoff_frequency" in arg_list:
             if self._args.cutoff_frequency:
                 self._confs["cutoff_frequency"] = self._args.cutoff_frequency
 
         if "displacement_distance" in arg_list:
-            if self._args.displacement_distance:
+            if self._args.displacement_distance is not None:
                 self._confs["displacement_distance"] = self._args.displacement_distance
 
+        if "displacement_distance_max" in arg_list:
+            if self._args.displacement_distance_max is not None:
+                self._confs["displacement_distance_max"] = (
+                    self._args.displacement_distance_max
+                )
+
         if "dynamical_matrix_decimals" in arg_list:
             if self._args.dynamical_matrix_decimals:
                 self._confs["dm_decimals"] = self._args.dynamical_matrix_decimals
@@ -713,7 +733,7 @@ class ConfParser:
                 if matrix.shape == (3, 3):
                     if np.linalg.det(matrix) < 1:
                         self.setting_error(
-                            "Determinant of supercell matrix has to be " "positive."
+                            "Determinant of supercell matrix has to be positive."
                         )
                     else:
                         self.set_parameter("supercell_matrix", matrix)
@@ -758,6 +778,12 @@ class ConfParser:
                     "displacement_distance", float(confs["displacement_distance"])
                 )
 
+            if conf_key == "displacement_distance_max":
+                self.set_parameter(
+                    "displacement_distance_max",
+                    float(confs["displacement_distance_max"]),
+                )
+
             if conf_key == "diag":
                 if confs["diag"].lower() == ".false.":
                     self.set_parameter("diag", False)
@@ -766,9 +792,9 @@ class ConfParser:
 
             if conf_key == "pm":
                 if confs["pm"].lower() == ".false.":
-                    self.set_parameter("pm_displacement", False)
+                    self.set_parameter("pm", False)
                 elif confs["pm"].lower() == ".true.":
-                    self.set_parameter("pm_displacement", True)
+                    self.set_parameter("pm", True)
 
             if conf_key == "trigonal":
                 if confs["trigonal"].lower() == ".false.":
@@ -887,7 +913,7 @@ class ConfParser:
                 q_direction = [fracval(x) for x in confs["q_direction"].split()]
                 if len(q_direction) < 3:
                     self.setting_error(
-                        "Number of elements of q_direction " "is less than 3"
+                        "Number of elements of q_direction is less than 3"
                     )
                 else:
                     self.set_parameter("nac_q_direction", q_direction)
@@ -913,6 +939,12 @@ class ConfParser:
                 val = float(confs["cutoff_frequency"])
                 self.set_parameter("cutoff_frequency", val)
 
+            if conf_key == "classical":
+                if confs["classical"].lower() == ".false.":
+                    self.set_parameter("classical", False)
+                elif confs["classical"].lower() == ".true.":
+                    self.set_parameter("classical", True)
+
             if conf_key == "sigma":
                 vals = [float(x) for x in str(confs["sigma"]).split()]
                 if len(vals) == 1:
@@ -977,9 +1009,14 @@ class ConfParser:
 
             # Number of supercells with random displacements
             if conf_key == "random_displacements":
-                self.set_parameter(
-                    "random_displacements", int(confs["random_displacements"])
-                )
+                rd = confs["random_displacements"]
+                if rd.lower() == "auto":
+                    self.set_parameter("random_displacements", "auto")
+                else:
+                    try:
+                        self.set_parameter("random_displacements", int(rd))
+                    except ValueError:
+                        self.setting_error(f"{conf_key.upper()} is incorrectly set.")
 
             if conf_key == "random_seed":
                 self.set_parameter("random_seed", int(confs["random_seed"]))
@@ -1008,6 +1045,10 @@ class ConfParser:
         if "create_displacements" in params:
             self._settings.set_create_displacements(params["create_displacements"])
 
+        # Treat statistics classically?
+        if "classical" in params:
+            self._settings.set_classical(params["classical"])
+
         # Cutoff frequency
         if "cutoff_frequency" in params:
             self._settings.set_cutoff_frequency(params["cutoff_frequency"])
@@ -1020,6 +1061,11 @@ class ConfParser:
         if "displacement_distance" in params:
             self._settings.set_displacement_distance(params["displacement_distance"])
 
+        if "displacement_distance_max" in params:
+            self._settings.set_displacement_distance_max(
+                params["displacement_distance_max"]
+            )
+
         # Decimals of values of dynamical matrxi
         if "dm_decimals" in params:
             self._settings.set_dm_decimals(int(params["dm_decimals"]))
@@ -1108,8 +1154,8 @@ class ConfParser:
             self._settings.set_masses(params["mass"])
 
         # Plus minus displacement
-        if "pm_displacement" in params:
-            self._settings.set_is_plusminus_displacement(params["pm_displacement"])
+        if "pm" in params:
+            self._settings.set_is_plusminus_displacement(params["pm"])
 
         # Primitive cell shape
         if "primitive_axes" in params:
@@ -1235,7 +1281,7 @@ class PhonopySettings(Settings):
         "is_projected_thermal_properties": False,
         "include_force_constants": False,
         "include_force_sets": False,
-        "include_nac_params": False,
+        "include_nac_params": True,
         "include_displacements": False,
         "lapack_solver": False,
         "mesh_shift": None,
@@ -1251,7 +1297,8 @@ class PhonopySettings(Settings):
         "readfc_format": "text",
         "run_mode": None,
         "show_irreps": False,
-        "store_dense_svecs": False,
+        "sscha_iterations": None,
+        "store_dense_svecs": True,
         "thermal_atom_pairs": None,
         "thermal_displacement_matrix_temperatue": None,
         "write_dynamical_matrices": False,
@@ -1477,6 +1524,10 @@ class PhonopySettings(Settings):
         """Set show_irreps."""
         self._v["show_irreps"] = val
 
+    def set_sscha_iterations(self, val):
+        """Set sscha_iterations."""
+        self._v["sscha_iterations"] = val
+
     def set_store_dense_svecs(self, val):
         """Set store_dense_svecs."""
         self._v["store_dense_svecs"] = val
@@ -1755,16 +1806,22 @@ class PhonopyConfParser(ConfParser):
         if "store_dense_svecs" in arg_list:
             if self._args.store_dense_svecs:
                 self._confs["store_dense_svecs"] = ".true."
+            else:
+                self._confs["store_dense_svecs"] = ".false."
 
         if "lapack_solver" in arg_list:
             if self._args.lapack_solver:
                 self._confs["lapack_solver"] = ".true."
 
-        # Overwrite
         if "is_check_symmetry" in arg_list:
             if self._args.is_check_symmetry:
-                # Dummy 'dim' setting for sym-check
-                self._confs["dim"] = "1 1 1"
+                if "dim" not in self._confs:
+                    # Dummy 'dim' setting not to exit by no-dim check.
+                    self._confs["dim"] = "1 1 1"
+
+        if "sscha_iterations" in arg_list:
+            if self._args.sscha_iterations:
+                self._confs["sscha_iterations"] = self._args.sscha_iterations
 
     def _parse_conf(self):
         ConfParser.parse_conf(self)
@@ -2098,6 +2155,11 @@ class PhonopyConfParser(ConfParser):
                 if confs["store_dense_svecs"].lower() == ".true.":
                     self.set_parameter("store_dense_svecs", True)
 
+            # SSCHA
+            if conf_key == "sscha_iterations":
+                val = int(confs["sscha_iterations"])
+                self.set_parameter("sscha_iterations", val)
+
     def _parse_conf_modulation(self, conf_modulation):
         modulation = {}
         modulation["dimension"] = [1, 1, 1]
@@ -2434,3 +2496,7 @@ class PhonopyConfParser(ConfParser):
 
         if "mesh_numbers" in params and "band_paths" in params:
             self._settings.set_run_mode("band_mesh")
+
+        # SSCHA
+        if "sscha_iterations" in params:
+            self._settings.set_sscha_iterations(params["sscha_iterations"])
