@@ -124,11 +124,12 @@ class DynamicalMatrix:
 
         self._dtype_complex = "c%d" % (np.dtype("double").itemsize * 2)
 
-        self._p2s_map = np.array(self._pcell.p2s_map, dtype="int_")
-        self._s2p_map = np.array(self._pcell.s2p_map, dtype="int_")
+        self._p2s_map = np.array(self._pcell.p2s_map, dtype="int64")
+        self._s2p_map = np.array(self._pcell.s2p_map, dtype="int64")
         p2p_map = self._pcell.p2p_map
         self._s2pp_map = np.array(
-            [p2p_map[self._s2p_map[i]] for i in range(len(self._s2p_map))], dtype="int_"
+            [p2p_map[self._s2p_map[i]] for i in range(len(self._s2p_map))],
+            dtype="int64",
         )
         svecs, multi = self._pcell.get_smallest_vectors()
         if self._pcell.store_dense_svecs:
@@ -655,8 +656,7 @@ class DynamicalMatrixGL(DynamicalMatrixNAC):
             self._run_c_recip_dipole_dipole_q0()
         except ImportError:
             print(
-                "Python version of dipole-dipole calculation is not well "
-                "implemented."
+                "Python version of dipole-dipole calculation is not well implemented."
             )
             sys.exit(1)
 
@@ -698,9 +698,7 @@ class DynamicalMatrixGL(DynamicalMatrixNAC):
 
     def show_nac_message(self):
         """Show message on Gonze-Lee NAC method."""
-        print(
-            "Use NAC by Gonze et al. (no real space sum in current " "implementation)"
-        )
+        print("Use NAC by Gonze et al. (no real space sum in current implementation)")
         print("  PRB 50, 13035(R) (1994), PRB 55, 10355 (1997)")
         print(
             "  G-cutoff distance: %4.2f, Number of G-points: %d, "
@@ -750,8 +748,7 @@ class DynamicalMatrixGL(DynamicalMatrixNAC):
             C_recip = self._get_c_recip_dipole_dipole(q_cart, q_dir_cart)
         except ImportError:
             print(
-                "Python version of dipole-dipole calculation is not well "
-                "implemented."
+                "Python version of dipole-dipole calculation is not well implemented."
             )
             sys.exit(1)
 
@@ -930,7 +927,7 @@ class DynamicalMatrixGL(DynamicalMatrixNAC):
         Therefore, another way is used although it can be slower.
 
         """
-        # pts = np.arange(-g_rad, g_rad + 1, dtype="int_")
+        # pts = np.arange(-g_rad, g_rad + 1, dtype="int64")
         # grid = np.r_["-1,2,0", np.meshgrid(pts, pts, pts)].reshape(3, -1)
         # return (self._rec_lat @ grid).T
         npts = g_rad * 2 + 1
@@ -1027,7 +1024,7 @@ class DynamicalMatrixWang(DynamicalMatrixNAC):
     def show_nac_message(self):
         """Show Wang et al.'s paper reference."""
         if self._log_level:
-            print("NAC by Wang et al., J. Phys. Condens. Matter 22, " "202201 (2010)")
+            print("NAC by Wang et al., J. Phys. Condens. Matter 22, 202201 (2010)")
 
     def _set_nac_params(self, nac_params):
         """Set NAC parameters.
@@ -1203,29 +1200,35 @@ def run_dynamical_matrix_solver_c(
     ) = _extract_params(dm)
 
     use_Wang_NAC = False
-    if _is_nac and dm.nac_method == "gonze":
-        gonze_nac_dataset = dm.Gonze_nac_dataset
-        if gonze_nac_dataset[0] is None:
-            dm.make_Gonze_nac_dataset()
+    if _is_nac:
+        if dm.nac_method == "gonze":
             gonze_nac_dataset = dm.Gonze_nac_dataset
-        (
-            gonze_fc,  # fc where the dipole-diple contribution is removed.
-            dd_q0,  # second term of dipole-dipole expression.
-            G_cutoff,  # Cutoff radius in reciprocal space. This will not be used.
-            G_list,  # List of G points where d-d interactions are integrated.
-            Lambda,
-        ) = gonze_nac_dataset  # Convergence parameter
-        fc = gonze_fc
+            if gonze_nac_dataset[0] is None:
+                dm.make_Gonze_nac_dataset()
+                gonze_nac_dataset = dm.Gonze_nac_dataset
+            (
+                gonze_fc,  # fc where the dipole-diple contribution is removed.
+                dd_q0,  # second term of dipole-dipole expression.
+                G_cutoff,  # Cutoff radius in reciprocal space. This will not be used.
+                G_list,  # List of G points where d-d interactions are integrated.
+                Lambda,
+            ) = gonze_nac_dataset  # Convergence parameter
+            fc = gonze_fc
+        if dm.nac_method == "wang":
+            use_Wang_NAC = True
+            dd_q0 = np.zeros((len(positions), 3, 3), dtype="double", order="C")
+            G_list = np.zeros((1, 3), dtype="double", order="C")  # dummy value
+            Lambda = 0.0
+            fc = dm.force_constants
     else:
-        dd_q0 = np.zeros(2)  # dummy value
-        G_list = np.zeros(3)  # dummy value
-        Lambda = 0.0  # dummy value
+        dd_q0 = np.zeros((len(positions), 3, 3), dtype="double", order="C")
+        G_list = np.zeros((1, 3), dtype="double", order="C")  # dummy value
+        Lambda = 0.0
         fc = dm.force_constants
-        use_Wang_NAC = _is_nac and dm.nac_method == "wang"
 
     if nac_q_direction is None:
         is_nac_q_zero = True
-        _nac_q_direction = np.zeros(3)  # dummy variable
+        _nac_q_direction = np.zeros(3, dtype="double")  # dummy variable
     else:
         is_nac_q_zero = False
         _nac_q_direction = np.array(nac_q_direction, dtype="double")
@@ -1233,7 +1236,10 @@ def run_dynamical_matrix_solver_c(
     p2s, s2p = _get_fc_elements_mapping(dm, fc)
 
     dtype_complex = "c%d" % (np.dtype("double").itemsize * 2)
-    dynmat = np.zeros((len(qpoints), len(p2s) * 3, len(p2s) * 3), dtype=dtype_complex)
+    dynmat = np.zeros(
+        (len(qpoints), len(p2s) * 3, len(p2s) * 3), dtype=dtype_complex, order="C"
+    )
+
     phonoc.dynamical_matrices_with_dd_openmp_over_qpoints(
         dynmat.view(dtype="double"),
         _qpoints,
@@ -1299,11 +1305,11 @@ def _get_fc_elements_mapping(dm: DynamicalMatrix, fc: np.ndarray):
     p2s_map = dm.primitive.p2s_map
     s2p_map = dm.primitive.s2p_map
     if fc.shape[0] == fc.shape[1]:  # full fc
-        return np.array(p2s_map, dtype="int_"), np.array(s2p_map, dtype="int_")
+        return np.array(p2s_map, dtype="int64"), np.array(s2p_map, dtype="int64")
     else:  # compact fc
         primitive = dm.primitive
         p2p_map = primitive.p2p_map
         s2pp_map = np.array(
-            [p2p_map[s2p_map[i]] for i in range(len(s2p_map))], dtype="int_"
+            [p2p_map[s2p_map[i]] for i in range(len(s2p_map))], dtype="int64"
         )
-        return np.arange(len(p2s_map), dtype="int_"), s2pp_map
+        return np.arange(len(p2s_map), dtype="int64"), s2pp_map
