@@ -43,7 +43,7 @@ from typing import Union
 import numpy as np
 
 from phonopy.interface.vasp import check_forces, get_drift_forces
-from phonopy.structure.atoms import PhonopyAtoms
+from phonopy.structure.atoms import PhonopyAtoms, atom_data
 from phonopy.structure.cells import get_cell_matrix_from_lattice
 
 
@@ -137,7 +137,7 @@ class LammpsStructureDumper:
         """Init method."""
         lattice = get_cell_matrix_from_lattice(cell.cell)
         lmps_cell = PhonopyAtoms(
-            cell=lattice, scaled_positions=cell.scaled_positions, numbers=cell.numbers
+            cell=lattice, scaled_positions=cell.scaled_positions, symbols=cell.symbols
         )
         self._run(lmps_cell)
 
@@ -327,8 +327,9 @@ class LammpsStructureLoader:
                 cell=lattice, positions=self._atom_positions, symbols=self._atom_labels
             )
         else:
+            symbols = [atom_data[n][1] for n in self._atom_labels]
             self._cell = PhonopyAtoms(
-                cell=lattice, positions=self._atom_positions, numbers=self._atom_labels
+                cell=lattice, positions=self._atom_positions, symbols=symbols
             )
 
     def _parse_AtomTypeLabels(self, lines):
@@ -350,8 +351,8 @@ class LammpsStructureLoader:
         if self._atom_type_labels:
             lables = []
         else:
-            lables = np.zeros(self._header_tags["atoms"], dtype="int_")
-        ids = np.zeros(self._header_tags["atoms"], dtype="int_")
+            lables = np.zeros(self._header_tags["atoms"], dtype="int64")
+        ids = np.zeros(self._header_tags["atoms"], dtype="int64")
         num_atoms = 0
         for line in lines:
             _line = line.split("#")[0].strip()
@@ -373,9 +374,9 @@ class LammpsStructureLoader:
             num_atoms += 1
             if num_atoms == self._header_tags["atoms"]:
                 break
-        assert (
-            num_atoms == self._header_tags["atoms"]
-        ), f'{num_atoms} != {self._header_tags["atoms"]}'
+        assert num_atoms == self._header_tags["atoms"], (
+            f"{num_atoms} != {self._header_tags['atoms']}"
+        )
         self._atom_ids = ids
         self._atom_labels = lables
         self._atom_positions = positions
