@@ -141,8 +141,10 @@ class PhonopyYamlLoaderBase(ABC):
 
     def _parse_command_header(self):
         if self._data.command_name in self._yaml:
-            header = self._yaml[self._data.command_name]
-            self._data.version = header["version"]
+            if self._data.command_name in self._yaml:
+                header = self._yaml[self._data.command_name]
+                if "version" in header:
+                    self._data.version = header["version"]
 
     def _parse_physical_units(self):
         if "physical_unit" in self._yaml:
@@ -200,6 +202,7 @@ class PhonopyYamlLoaderBase(ABC):
                 natom = len(supercell)
             else:
                 natom = None
+
             disp = self._yaml[f"{key_prefix}displacements"][0]
             if isinstance(disp, dict):  # type1
                 dataset = self._parse_force_sets_type1(
@@ -457,17 +460,18 @@ class PhonopyYamlDumperBase(ABC):
 
         dataset = self._data.symmetry.dataset
         if dataset is not None:
-            if "uni_number" in dataset:
+            try:
+                uni_number = dataset.uni_number
                 lines.append("magnetic_space_group:")
-                lines.append(f'  uni_number: {dataset["uni_number"]}')
-                lines.append(f'  msg_type: {dataset["msg_type"]}')
+                lines.append(f"  uni_number: {uni_number}")
+                lines.append(f"  msg_type: {dataset.msg_type}")
                 lines.append("")
-            else:
+            except AttributeError:
                 lines.append("space_group:")
-                spg_type = dataset["international"]
+                spg_type = dataset.international
                 lines.append(f'  type: "{spg_type}"')
-                lines.append(f'  number: {dataset["number"]}')
-                hall_symbol = dataset["hall"]
+                lines.append(f"  number: {dataset.number}")
+                hall_symbol = dataset.hall
                 if '"' in hall_symbol:
                     hall_symbol = hall_symbol.replace('"', '\\"')
                 lines.append(f'  Hall_symbol: "{hall_symbol}"')
@@ -489,7 +493,7 @@ class PhonopyYamlDumperBase(ABC):
     def _primitive_matrix_yaml_lines(self, matrix, name):
         lines = []
         if matrix is not None:
-            lines.append("%s:" % name)
+            lines.append(f"{name}:")
             for v in matrix:
                 lines.append("- [ %18.15f, %18.15f, %18.15f ]" % tuple(v))
             lines.append("")
@@ -498,7 +502,7 @@ class PhonopyYamlDumperBase(ABC):
     def _supercell_matrix_yaml_lines(self, matrix, name):
         lines = []
         if matrix is not None:
-            lines.append("%s:" % name)
+            lines.append(f"{name}:")
             for v in matrix:
                 lines.append("- [ %3d, %3d, %3d ]" % tuple(v))
             lines.append("")
@@ -582,9 +586,9 @@ class PhonopyYamlDumperBase(ABC):
                     if self._data.nac_params["method"].lower() == "wang":
                         lines.append('  method: "Wang"')
                 if "factor" in self._data.nac_params:
-                    lines.append(
-                        "  unit_conversion_factor: %f" % self._data.nac_params["factor"]
-                    )
+                    factor = self._data.nac_params["factor"]
+                    # if factor is not None:
+                    lines.append("  unit_conversion_factor: %f" % factor)
                 lines.insert(0, "nac:")
                 lines.append("")
         return lines
@@ -818,7 +822,7 @@ class PhonopyYaml:
 
     """
 
-    default_filenames = ("phonopy_params.yaml", "phonopy_disp.yaml", "phonopy.yaml")
+    default_filenames = ("phonopy_disp.yaml", "phonopy.yaml")
     command_name = "phonopy"
 
     configuration = phonopy_yaml_property_factory("configuration")
@@ -879,7 +883,7 @@ class PhonopyYaml:
         )
         return self
 
-    def set_phonon_info(self, phonopy: "Phonopy"):
+    def set_phonon_info(self, phonopy: "Phonopy") -> PhonopyYaml:
         """Collect data from Phonopy instance."""
         self._data.unitcell = phonopy.unitcell
         self._data.primitive = phonopy.primitive
@@ -893,6 +897,7 @@ class PhonopyYaml:
         self._data.calculator = phonopy.calculator
         self._data.force_constants = phonopy.force_constants
         self._data.dataset = phonopy.dataset
+        return self
 
 
 def read_phonopy_yaml(
