@@ -50,9 +50,9 @@ from phonopy.interface.vasp import (
     get_drift_forces,
     get_scaled_positions_lines,
 )
+from phonopy.physical_units import get_physical_units
 from phonopy.structure.atoms import PhonopyAtoms, split_symbol_and_index, symbol_map
 from phonopy.structure.cells import get_primitive, get_supercell
-from phonopy.units import Bohr
 
 
 def parse_set_of_forces(num_atoms, forces_filenames, verbose=True):
@@ -209,6 +209,7 @@ class PwscfIn:
             ("atomic_species", "_set_atom_types"),
             ("atomic_positions", "_set_positions"),
             ("cell_parameters", "_set_lattice"),
+            ("k_points", "_set_kpoints"),
         ]
     )
 
@@ -310,7 +311,7 @@ class PwscfIn:
             else:
                 factor = self._tags["celldm(1)"]  # in Bohr
         elif "angstrom" in unit:
-            factor = 1.0 / Bohr
+            factor = 1.0 / get_physical_units().Bohr
         elif "bohr" in unit:
             factor = 1.0
         else:
@@ -337,7 +338,7 @@ class PwscfIn:
         unit = self._values[0].lower()
         factor = 1.0
         if "angstrom" in unit:
-            factor = 1.0 / Bohr
+            factor = 1.0 / get_physical_units().Bohr
             self._cartesian_positions = True
         elif "bohr" in unit:
             self._cartesian_positions = True
@@ -392,6 +393,10 @@ class PwscfIn:
 
         self._tags["atomic_species"] = species
 
+    def _set_kpoints(self):
+        """Set k-points."""
+        pass
+
 
 class PH_Q2R:
     """Parse QE/q2r output and create supercell force constants array.
