@@ -53,9 +53,9 @@ from phonopy.file_IO import (
     write_FORCE_CONSTANTS,
     write_force_constants_to_hdf5,
 )
+from phonopy.physical_units import get_physical_units
 from phonopy.structure.atoms import PhonopyAtoms, atom_data, symbol_map
 from phonopy.structure.symmetry import elaborate_borns_and_epsilon
-from phonopy.units import VaspToTHz
 
 
 def check_forces(forces, num_atom, filename, verbose=True):
@@ -99,7 +99,9 @@ def get_scaled_positions_lines(scaled_positions):
     return "\n".join(_get_scaled_positions_lines(scaled_positions))
 
 
-def sort_positions_by_symbols(symbols: Sequence, positions: np.ndarray):
+def sort_positions_by_symbols(
+    symbols: Sequence, positions: Optional[np.ndarray] = None
+):
     """Sort atomic positions by symbols.
 
     Sort positions by symbols (using the order defined by reduced_symbols)
@@ -117,8 +119,8 @@ def sort_positions_by_symbols(symbols: Sequence, positions: np.ndarray):
     symbols : list[str] or list[int] or np.ndarray[int]
         Sequence of hashable objects. This may be a list of chemical symbols
         or numbers.
-    positions : np.ndarray
-        Atomic positions.
+    positions : np.ndarray or None, optional
+        Atomic positions. When None, sorted_positions is also None.
 
     Returns
     -------
@@ -144,7 +146,11 @@ def sort_positions_by_symbols(symbols: Sequence, positions: np.ndarray):
     counts_list = [counts_dict[s] for s in reduced_symbols]
     sort_keys = [reduced_symbols.index(i) for i in symbols]
     perm = _argsort_stable(sort_keys)
-    sorted_positions = positions[perm]
+
+    if positions is None:
+        sorted_positions = None
+    else:
+        sorted_positions = positions[perm]
 
     return counts_list, reduced_symbols, sorted_positions, perm
 
@@ -730,7 +736,7 @@ class Vasprun:
 
             # Recover the unit of eV/Angstrom^2 for VASP-6.
             if hessian_units == "THz^2":
-                force_constants /= VaspToTHz**2
+                force_constants /= get_physical_units().DefaultToTHz ** 2
 
             return force_constants, elements
 
