@@ -37,9 +37,9 @@
 import numpy as np
 
 from phonopy.interface.vasp import write_vasp
+from phonopy.physical_units import get_physical_units
 from phonopy.structure.atoms import PhonopyAtoms
 from phonopy.structure.cells import get_angles, get_cell_matrix, get_cell_parameters
-from phonopy.units import VaspToTHz
 
 
 def write_animation(
@@ -143,10 +143,19 @@ class Animation:
 
         self._displacements = np.array(u).reshape(-1, 3)
 
-    def write_v_sim(self, amplitude=None, factor=VaspToTHz, filename="anime.ascii"):
+    def write_v_sim(
+        self,
+        amplitude=None,
+        factor=None,
+        filename="anime.ascii",
+    ):
         """Write to file in v_sim format."""
         if amplitude is None:
             _amplitude = 1.0
+        if factor is None:
+            _factor = get_physical_units().DefaultToTHz
+        else:
+            _factor = factor
         self._set_cell_oriented()
         lat = self._lattice_oriented
         q = self._qpoint
@@ -166,7 +175,7 @@ class Animation:
                 q[0],
                 q[1],
                 q[2],
-                omega * factor,
+                omega * _factor,
             )
             for u in self._get_oriented_displacements(self._displacements) * _amplitude:
                 text += "#; %f; %f; %f; %f; %f; %f \\\n" % (
@@ -237,8 +246,17 @@ class Animation:
 
         return filename
 
-    def write_xyz_jmol(self, amplitude=10, factor=VaspToTHz, filename="anime.xyz_jmol"):
+    def write_xyz_jmol(
+        self,
+        amplitude=10,
+        factor=None,
+        filename="anime.xyz_jmol",
+    ):
         """Write to file in jmol xyz format."""
+        if factor is None:
+            _factor = get_physical_units().DefaultToTHz
+        else:
+            _factor = factor
         self._set_cell_oriented()
         text = ""
         for i, val in enumerate(self._eigenvalues):
@@ -251,7 +269,7 @@ class Animation:
                 self._get_oriented_displacements(self._displacements) * amplitude
             )
             text += "%d\n" % len(self._symbols)
-            text += "q %s , b %d , f %f " % (str(self._qpoint), i + 1, freq * factor)
+            text += "q %s , b %d , f %f " % (str(self._qpoint), i + 1, freq * _factor)
             text += "(generated by Phonopy)\n"
             for s, p, u in zip(self._symbols, self._positions_oriented, displacements):
                 text += "%-3s  %22.15f %22.15f %22.15f  " % (s, p[0], p[1], p[2])
@@ -267,10 +285,14 @@ class Animation:
         band_index,
         amplitude=1,
         num_div=20,
-        factor=VaspToTHz,
+        factor=None,
         filename="anime.xyz",
     ):
         """Write to file in xyz format."""
+        if factor is None:
+            _factor = get_physical_units().DefaultToTHz
+        else:
+            _factor = factor
         self._set_cell_oriented()
         freq = self._eigenvalues[band_index - 1]
         self._set_displacements(band_index - 1)
@@ -281,7 +303,7 @@ class Animation:
             text += "q %s , b %d , f %f , " % (
                 str(self._qpoint),
                 band_index,
-                freq * factor,
+                freq * _factor,
             )
             text += "div %d / %d " % (i, num_div)
             text += "(generated by Phonopy)\n"
