@@ -86,8 +86,8 @@ class Dos:
                 mesh_object.dynamical_matrix.primitive,
                 self._frequencies,
                 mesh_object.mesh_numbers,
-                np.array(mesh_object.grid_address, dtype="int_"),
-                np.array(mesh_object.grid_mapping_table, dtype="int_"),
+                np.array(mesh_object.grid_address, dtype="int64"),
+                np.array(mesh_object.grid_mapping_table, dtype="int64"),
                 mesh_object.ir_grid_points,
             )
         self._frequency_points = None
@@ -659,12 +659,11 @@ def plot_projected_dos(
         for i in set_for_sum:
             if i > num_pdos - 1:
                 print("Index number '%d' is specified," % (i + 1))
-                print("but it is not allowed to be larger than the number of " "atoms.")
+                print("but it is not allowed to be larger than the number of atoms.")
                 raise ValueError
             if i < 0:
                 print(
-                    "Index number '%d' is specified, but it must be "
-                    "positive." % (i + 1)
+                    "Index number '%d' is specified, but it must be positive." % (i + 1)
                 )
                 raise ValueError
             pdos_sum += projected_dos[i]
@@ -708,12 +707,12 @@ def run_tetrahedron_method_dos(
 
     phonoc.tetrahedron_method_dos(
         dos,
-        np.array(mesh, dtype="int_"),
+        np.array(mesh, dtype="int64"),
         frequency_points,
         frequencies,
         _coef,
-        np.array(grid_address, dtype="int_", order="C"),
-        np.array(grid_mapping_table, dtype="int_", order="C"),
+        np.array(grid_address, dtype="int64", order="C"),
+        np.array(grid_mapping_table, dtype="int64", order="C"),
         relative_grid_address,
     )
     if coef is None:
