@@ -47,9 +47,9 @@ from phonopy.harmonic.dynmat_to_fc import (
     categorize_commensurate_points,
     get_commensurate_points_in_integers,
 )
+from phonopy.physical_units import get_physical_units
 from phonopy.structure.atoms import PhonopyAtoms
 from phonopy.structure.cells import Primitive
-from phonopy.units import AMU, EV, Angstrom, Hbar, Kb, THz, THzToEv, VaspToTHz
 
 
 def bose_einstein_dist(
@@ -70,7 +70,9 @@ def bose_einstein_dist(
         Phonon occupation numbers.
 
     """
-    return 1.0 / (np.exp(THzToEv * x / (Kb * t)) - 1)
+    return 1.0 / (
+        np.exp(get_physical_units().THzToEv * x / (get_physical_units().KB * t)) - 1
+    )
 
 
 class RandomDisplacements:
@@ -132,7 +134,7 @@ class RandomDisplacements:
         dist_func: Optional[str] = None,
         cutoff_frequency: Optional[float] = None,
         max_distance: Optional[float] = None,
-        factor: float = VaspToTHz,
+        factor: Optional[float] = None,
         use_openmp: bool = False,
     ):
         """Init method.
@@ -171,7 +173,12 @@ class RandomDisplacements:
         else:
             self._cutoff_frequency = cutoff_frequency
         self._max_distance = max_distance
-        self._factor = factor
+
+        _physical_units = get_physical_units()
+        if factor is None:
+            self._factor = _physical_units.DefaultToTHz
+        else:
+            self._factor = factor
         self._T = None
         self._u = None
 
@@ -182,9 +189,20 @@ class RandomDisplacements:
         else:
             raise RuntimeError("Either 'quantum' or 'classical' is required.")
 
-        self._unit_conversion = Hbar * EV / AMU / THz / (2 * np.pi) / Angstrom**2
+        self._unit_conversion = (
+            _physical_units.Hbar
+            * _physical_units.EV
+            / _physical_units.AMU
+            / _physical_units.THz
+            / (2 * np.pi)
+            / _physical_units.Angstrom**2
+        )
         self._unit_conversion_classical = (
-            Kb * EV / AMU / (THz * (2 * np.pi)) ** 2 / Angstrom**2
+            _physical_units.KB
+            * _physical_units.EV
+            / _physical_units.AMU
+            / (_physical_units.THz * (2 * np.pi)) ** 2
+            / _physical_units.Angstrom**2
         )
 
         # Dynamical matrix without NAC because of commensurate points only
