@@ -44,6 +44,7 @@ import spglib
 
 from phonopy.structure.atoms import PhonopyAtoms
 from phonopy.structure.snf import SNF3x3
+from phonopy.utils import get_dot_access_dataset
 
 
 class Supercell(PhonopyAtoms):
@@ -138,7 +139,7 @@ class Supercell(PhonopyAtoms):
         Returns
         -------
         ndarray
-            shape=(num_atoms_in_supercell, ), dtype='int_'
+            shape=(num_atoms_in_supercell, ), dtype='int64'
 
         """
         return self._s2u_map
@@ -163,7 +164,7 @@ class Supercell(PhonopyAtoms):
         Returns
         -------
         ndarray
-            shape=(num_atoms_in_unitcell, ), dtype='int_'
+            shape=(num_atoms_in_unitcell, ), dtype='int64'
 
         """
         return self._u2s_map
@@ -237,22 +238,21 @@ class Supercell(PhonopyAtoms):
         if N != determinant(self._supercell_matrix):
             print("Supercell creation failed.")
             print(
-                "Probably some atoms are overwrapped. "
-                "The mapping table is given below."
+                "Probably some atoms are overwrapped. The mapping table is given below."
             )
             print(mapping_table)
             super().__init__()
         else:
             super().__init__(
-                numbers=supercell.numbers,
+                symbols=supercell.symbols,
                 masses=supercell.masses,
                 magnetic_moments=supercell.magnetic_moments,
                 scaled_positions=supercell.scaled_positions,
                 cell=supercell.cell,
             )
-            self._u2s_map = np.array(np.arange(num_uatom) * N, dtype="int_")
+            self._u2s_map = np.array(np.arange(num_uatom) * N, dtype="int64")
             self._u2u_map = {j: i for i, j in enumerate(self._u2s_map)}
-            self._s2u_map = np.array(u2sur_map[sur2s_map] * N, dtype="int_")
+            self._s2u_map = np.array(u2sur_map[sur2s_map] * N, dtype="int64")
 
     def _get_simple_supercell(self, unitcell: PhonopyAtoms, multi, P):
         if self._is_old_style:
@@ -263,7 +263,7 @@ class Supercell(PhonopyAtoms):
         # Scaled positions within the frame, i.e., create a supercell that
         # is made simply to multiply the input cell.
         positions = unitcell.scaled_positions
-        numbers = unitcell.numbers
+        symbols = unitcell.symbols
         masses = unitcell.masses
         magmoms = unitcell.magnetic_moments
         lattice = unitcell.cell
@@ -291,7 +291,7 @@ class Supercell(PhonopyAtoms):
             np.tile(lattice_points, (n, 1)) + np.repeat(positions, n_l, axis=0),
             np.linalg.inv(mat).T,
         )
-        numbers_multi = np.repeat(numbers, n_l)
+        symbols_multi = [s for s in symbols for _ in range(n_l)]
         atom_map = np.repeat(np.arange(n), n_l)
         if masses is None:
             masses_multi = None
@@ -305,7 +305,7 @@ class Supercell(PhonopyAtoms):
             magmoms_multi = [v for v in magmoms for _ in range(n_l)]
 
         simple_supercell = PhonopyAtoms(
-            numbers=numbers_multi,
+            symbols=symbols_multi,
             masses=masses_multi,
             magnetic_moments=magmoms_multi,
             scaled_positions=positions_multi,
@@ -339,25 +339,14 @@ class Supercell(PhonopyAtoms):
 
 
 class Primitive(PhonopyAtoms):
-    """Build primitive cell.
-
-    Attributes
-    ----------
-    primitive_matrix : ndarray
-    p2s_map : ndarray
-    s2p_map : ndarray
-    p2p_map : dict
-    atomic_permutations : ndarray
-    store_dense_svecs : bool
-
-    """
+    """Build primitive cell."""
 
     def __init__(
         self,
-        supercell,
+        supercell: PhonopyAtoms,
         primitive_matrix,
         symprec=1e-5,
-        store_dense_svecs=False,
+        store_dense_svecs=True,
         positions_to_reorder=None,
     ):
         """Init method.
@@ -367,19 +356,21 @@ class Primitive(PhonopyAtoms):
         supercell : PhonopyAtoms
             Supercell
         primitive_matrix : list of list or ndarray
-            Transformation matrix to transform supercell to primitive cell
-            such as:
+            Transformation matrix to transform supercell to primitive cell such
+            as:
                np.dot(primitive_matrix.T, supercell.cell)
             shape=(3,3)
-        symprec : float, optional, default=1e-5
-            Tolerance to find overlapping atoms in primitive cell.
-        store_dense_svecs : bool, optional, default=False
-            Shortest vectors are stored in a dense array. See `ShortestPairs`.
-        positions_to_reorder : array_like, optional, default=None
-            If atomic positions in a created primitive cell is known and
-            the order of atoms is expected to be sure, these positions with
-            the specific order is used after position matching between
-            this data and generated positions.
+        symprec : float, optional
+            Tolerance to find overlapping atoms in primitive cell. Default is
+            1e-5.
+        store_dense_svecs : bool, optional
+            Shortest vectors are stored in a dense array. Default is True. See
+            `ShortestPairs`.
+        positions_to_reorder : array_like, optional
+            If atomic positions in a created primitive cell is known and the
+            order of atoms is expected to be sure, these positions with the
+            specific order is used after position matching between this data and
+            generated positions. Default is None.
 
         """
         self._primitive_matrix = np.array(primitive_matrix, dtype="double", order="C")
@@ -512,7 +503,7 @@ class Primitive(PhonopyAtoms):
                 and primitive cell, and [1] integral of multiplicities to this
                 pair, i.e., which indicates address used in `shortest_vectors`.
                 In the dense format, shape=(size_super, size_prim, 2),
-                dtype='int_' dtype='intc', order='C'.
+                dtype='int64' dtype='intc', order='C'.
 
         """
         return self._smallest_vectors, self._multiplicity
@@ -552,7 +543,7 @@ class Primitive(PhonopyAtoms):
         """Return whether shortest vectors are stored in dense array or not."""
         return self._store_dense_svecs
 
-    def _run(self, supercell, positions_to_reorder=None):
+    def _run(self, supercell: PhonopyAtoms, positions_to_reorder=None):
         self._p2s_map = self._create_primitive_cell(
             supercell, positions_to_reorder=positions_to_reorder
         )
@@ -564,15 +555,30 @@ class Primitive(PhonopyAtoms):
         )
         self._atomic_permutations = self._get_atomic_permutations(supercell)
 
-    def _create_primitive_cell(self, supercell, positions_to_reorder=None):
-        trimmed_cell, p2s_map, _ = _trim_cell(
+    def _create_primitive_cell(
+        self, supercell: PhonopyAtoms, positions_to_reorder=None
+    ):
+        trimmed_cell, p2s_map, mapping_table = _trim_cell(
             self._primitive_matrix,
             supercell,
             symprec=self._symprec,
             positions_to_reorder=positions_to_reorder,
         )
+        mapped_symbols = [supercell.symbols[i] for i in mapping_table]
+        if supercell.symbols != mapped_symbols:
+            msg = [
+                "Atom symbol mapping failure.",
+                "Primitive cell could not be created.",
+            ]
+            msg.append("Primitive cell:")
+            for i, s in enumerate(trimmed_cell.symbols):
+                msg.append(f"  {i + 1}: {s}")
+            msg.append("Original cell:")
+            for i, (s1, s2) in enumerate(zip(supercell.symbols, mapped_symbols)):
+                msg.append(f"  {i + 1}: {s1} -> {s2}")
+            raise RuntimeError("\n".join(msg))
         super().__init__(
-            numbers=trimmed_cell.numbers,
+            symbols=trimmed_cell.symbols,
             masses=trimmed_cell.masses,
             magnetic_moments=trimmed_cell.magnetic_moments,
             scaled_positions=trimmed_cell.scaled_positions,
@@ -600,7 +606,7 @@ class Primitive(PhonopyAtoms):
 
         return s2p_map, p2p_map
 
-    def _get_atomic_permutations(self, supercell):
+    def _get_atomic_permutations(self, supercell: PhonopyAtoms):
         positions = supercell.scaled_positions
         diff = positions - positions[self._p2s_map[0]]
         trans = np.array(
@@ -741,7 +747,7 @@ class TrimmedCell(PhonopyAtoms):
 
         (
             trimmed_positions,
-            trimmed_numbers,
+            trimmed_symbols,
             trimmed_masses,
             trimmed_magmoms,
             extracted_atoms,
@@ -749,7 +755,7 @@ class TrimmedCell(PhonopyAtoms):
         ) = self._extract(
             positions_in_new_lattice,
             trimmed_lattice,
-            cell.numbers,
+            cell.symbols,
             cell.masses,
             cell.magnetic_moments,
             check_overlap,
@@ -761,7 +767,7 @@ class TrimmedCell(PhonopyAtoms):
                 positions_to_reorder, trimmed_positions, trimmed_lattice, symprec
             )
             trimmed_positions = trimmed_positions[ids]
-            trimmed_numbers = trimmed_numbers[ids]
+            trimmed_symbols = [trimmed_symbols[i] for i in ids]
             if trimmed_masses is not None:
                 trimmed_masses = trimmed_masses[ids]
             if trimmed_magmoms is not None:
@@ -770,9 +776,9 @@ class TrimmedCell(PhonopyAtoms):
 
         # scale is not always to become integer.
         scale = 1.0 / np.linalg.det(relative_axes)
-        if len(cell) == int(np.rint(scale * len(trimmed_numbers))):
+        if len(cell) == int(np.rint(scale * len(trimmed_symbols))):
             super().__init__(
-                numbers=trimmed_numbers,
+                symbols=trimmed_symbols,
                 masses=trimmed_masses,
                 magnetic_moments=trimmed_magmoms,
                 scaled_positions=trimmed_positions,
@@ -787,7 +793,7 @@ class TrimmedCell(PhonopyAtoms):
         self,
         positions_in_new_lattice,
         trimmed_lattice,
-        numbers,
+        symbols,
         masses,
         magmoms,
         check_overlap,
@@ -797,7 +803,7 @@ class TrimmedCell(PhonopyAtoms):
         extracted_atoms = []
         mapping_table = np.arange(len(positions_in_new_lattice), dtype="intc")
         trimmed_positions = np.zeros_like(positions_in_new_lattice)
-        trimmed_numbers = []
+        trimmed_symbols = []
         if masses is None:
             trimmed_masses = None
         else:
@@ -823,7 +829,7 @@ class TrimmedCell(PhonopyAtoms):
             if not found_overlap:
                 trimmed_positions[num_atoms] = pos
                 num_atoms += 1
-                trimmed_numbers.append(numbers[i])
+                trimmed_symbols.append(symbols[i])
                 if masses is not None:
                     trimmed_masses.append(masses[i])
                 if magmoms is not None:
@@ -837,7 +843,7 @@ class TrimmedCell(PhonopyAtoms):
 
         return (
             np.array(trimmed_positions[:num_atoms], dtype="double", order="C"),
-            np.array(trimmed_numbers, dtype="intc"),
+            trimmed_symbols,
             trimmed_masses,
             trimmed_magmoms,
             np.array(extracted_atoms, dtype="intc"),
@@ -872,7 +878,7 @@ def get_primitive(
     supercell: PhonopyAtoms,
     primitive_matrix: Optional[Union[str, np.ndarray, Sequence]] = None,
     symprec=1e-5,
-    store_dense_svecs=False,
+    store_dense_svecs=True,
     positions_to_reorder=None,
 ):
     """Create primitive cell."""
@@ -1032,7 +1038,11 @@ def convert_to_phonopy_primitive(
 
 
 def _trim_cell(
-    relative_axes, cell, check_overlap=True, symprec=1e-5, positions_to_reorder=None
+    relative_axes,
+    cell: PhonopyAtoms,
+    check_overlap=True,
+    symprec=1e-5,
+    positions_to_reorder=None,
 ):
     """Trim overlapping atoms."""
     tcell = TrimmedCell(
@@ -1042,7 +1052,7 @@ def _trim_cell(
         symprec=symprec,
         positions_to_reorder=positions_to_reorder,
     )
-    return (PhonopyAtoms(atoms=tcell), tcell.extracted_atoms, tcell.mapping_table)
+    return (tcell.copy(), tcell.extracted_atoms, tcell.mapping_table)
 
 
 #
@@ -1121,7 +1131,7 @@ class ShortestPairs:
         supercell_bases,
         supercell_pos,
         primitive_pos,
-        store_dense_svecs=False,
+        store_dense_svecs=True,
         symprec=1e-5,
     ):
         """Init method.
@@ -1140,7 +1150,7 @@ class ShortestPairs:
             shape=(size_prim, 3)
         store_dense_svecs_: bool, optional
             ``shortest_vectors`` are stored in the dense data structure.
-            Default is False.
+            Default is True.
         symprec : float, optional
             Tolerance to find equal distances of vectors. Default is 1e-5.
 
@@ -1193,7 +1203,7 @@ class ShortestPairs:
             and primitive cell, and [1] integral of multiplicities to
             this pair, i.e., which indicates address used in
             `shortest_vectors`.
-            shape=(size_super, size_prim, 2), dtype='int_'
+            shape=(size_super, size_prim, 2), dtype='int64'
 
         """
         (
@@ -1202,13 +1212,13 @@ class ShortestPairs:
             primitive_fracs,
             trans_mat_inv,
             reduced_bases,
-        ) = self._transform_cell_basis("int_")
+        ) = self._transform_cell_basis("int64")
 
         # Phase1 : Set multiplicity.
         # shortest_vectors is a dummy array.
         shortest_vectors = np.zeros((1, 3), dtype="double", order="C")
         multiplicity = np.zeros(
-            (len(supercell_fracs), len(primitive_fracs), 2), dtype="int_", order="C"
+            (len(supercell_fracs), len(primitive_fracs), 2), dtype="int64", order="C"
         )
         import phonopy._phonopy as phonoc
 
@@ -1219,7 +1229,7 @@ class ShortestPairs:
             primitive_fracs,
             lattice_points,
             np.array(reduced_bases.T, dtype="double", order="C"),
-            np.array(trans_mat_inv.T, dtype="int_", order="C"),
+            np.array(trans_mat_inv.T, dtype="int64", order="C"),
             1,
             self._symprec,
         )
@@ -1235,7 +1245,7 @@ class ShortestPairs:
             primitive_fracs,
             lattice_points,
             np.array(reduced_bases.T, dtype="double", order="C"),
-            np.array(trans_mat_inv.T, dtype="int_", order="C"),
+            np.array(trans_mat_inv.T, dtype="int64", order="C"),
             0,
             self._symprec,
         )
@@ -1289,7 +1299,7 @@ class ShortestPairs:
 
         return shortest_vectors, multiplicity
 
-    def _transform_cell_basis(self, int_dtype):
+    def _transform_cell_basis(self, longdtype):
         reduced_cell_method = "niggli"
         reduced_bases = get_reduced_bases(
             self._supercell_bases, method=reduced_cell_method, tolerance=self._symprec
@@ -1323,13 +1333,13 @@ class ShortestPairs:
                 for k in lattice_1D
                 for ll in lattice_1D
             ],
-            dtype=int_dtype,
+            dtype=longdtype,
             order="C",
         )
         bases = [[1, 0, 0], [0, 1, 0], [0, 0, 1], [-1, -1, -1]]
         lattice_points = np.dot(lattice_4D, bases)
         lattice_points = np.array(
-            np.unique(lattice_points, axis=0), dtype=int_dtype, order="C"
+            np.unique(lattice_points, axis=0), dtype=longdtype, order="C"
         )
 
         return (
@@ -1341,9 +1351,11 @@ class ShortestPairs:
         )
 
 
-def sparse_to_dense_svecs(svecs, multi):
+def sparse_to_dense_svecs(
+    svecs: np.ndarray, multi: np.ndarray
+) -> tuple[np.ndarray, np.ndarray]:
     """Convert sparse svecs to dense svecs."""
-    dmulti = np.zeros(multi.shape + (2,), dtype="int_", order="C")
+    dmulti = np.zeros(multi.shape + (2,), dtype="int64", order="C")
     dmulti[:, :, 0] = multi
     dsvecs = np.zeros((multi.sum(), 3), dtype="double", order="C")
     adrs = 0
@@ -1356,6 +1368,24 @@ def sparse_to_dense_svecs(svecs, multi):
     return dsvecs, dmulti
 
 
+def dense_to_sparse_svecs(
+    svecs: np.ndarray, multi: np.ndarray
+) -> tuple[np.ndarray, np.ndarray]:
+    """Convert dense svecs to sparse svecs."""
+    ssvecs = np.zeros(
+        (multi.shape[0], multi.shape[1], 27, 3),
+        dtype="double",
+        order="C",
+    )
+    smulti = np.zeros(multi.shape[:2], dtype="intc", order="C")
+    smulti[:, :] = multi[:, :, 0]
+    for s_i in range(multi.shape[0]):
+        for p_i in range(multi.shape[1]):
+            m = multi[s_i, p_i]
+            ssvecs[s_i, p_i, : m[0]] = svecs[m[1] : m[0] + m[1]]
+    return ssvecs, smulti
+
+
 def compute_all_sg_permutations(
     positions,  # scaled positions
     rotations,  # scaled
@@ -1691,7 +1721,7 @@ def get_primitive_matrix(
             if symprec < det and det < 1 + symprec:
                 _pmat = matrix
             else:
-                msg = "Determinant of primitive_matrix has to be larger " "than 0"
+                msg = "Determinant of primitive_matrix has to be larger than 0"
                 raise RuntimeError(msg)
     else:
         msg = (
@@ -1750,9 +1780,11 @@ def guess_primitive_matrix(unitcell: PhonopyAtoms, symprec: float = 1e-5):
         msg = "Can not be used with the unit cell having magnetic moments."
         raise RuntimeError(msg)
 
-    dataset = spglib.get_symmetry_dataset(unitcell.totuple(), symprec=symprec)
-    tmat = dataset["transformation_matrix"]
-    centring = dataset["international"][0]
+    dataset = get_dot_access_dataset(
+        spglib.get_symmetry_dataset(unitcell.totuple(), symprec=symprec)
+    )
+    tmat = dataset.transformation_matrix
+    centring = dataset.international[0]
     pmat = get_primitive_matrix_by_centring(centring)
     return np.array(np.dot(np.linalg.inv(tmat), pmat), dtype="double", order="C")
 
@@ -1796,9 +1828,9 @@ def estimate_supercell_matrix(spglib_dataset, max_num_atoms=120, max_iter=100):
         Multiplicities for a, b, c basis vectors, respectively.
 
     """
-    spg_num = spglib_dataset["number"]
-    num_atoms = len(spglib_dataset["std_types"])
-    lengths = get_cell_parameters(spglib_dataset["std_lattice"])
+    spg_num = spglib_dataset.number
+    num_atoms = len(spglib_dataset.std_types)
+    lengths = get_cell_parameters(spglib_dataset.std_lattice)
     if spg_num <= 74:  # Triclinic, monoclinic, and orthorhombic
         multi = _get_multiplicity_abc(
             num_atoms, lengths, max_num_atoms, max_iter=max_iter
