@@ -58,7 +58,7 @@ from phonopy.structure.symmetry import (
     get_lattice_vector_equivalence,
     get_pointgroup_operations,
 )
-from phonopy.utils import similarity_transformation
+from phonopy.utils import get_dot_access_dataset, similarity_transformation
 from phonopy.version import __version__
 
 
@@ -79,7 +79,7 @@ def length2mesh(length, lattice, rotations=None):
     rotations: array_like, optional
         Rotation matrices in real space. When given, mesh numbers that are
         symmetrically reasonable are returned. Default is None.
-        dtype='int_', shape=(rotations, 3, 3)
+        dtype='int64', shape=(rotations, 3, 3)
 
     Returns
     -------
@@ -134,7 +134,9 @@ def get_qpoints(
     return gp.qpoints, gp.weights
 
 
-def extract_ir_grid_points(grid_mapping_table):
+def extract_ir_grid_points(
+    grid_mapping_table: np.ndarray,
+) -> tuple[np.ndarray, np.ndarray]:
     """Return ir-grid points and weights in grid index mapping table."""
     dtype = grid_mapping_table.dtype
     ir_grid_points = np.array(np.unique(grid_mapping_table), dtype=dtype)
@@ -166,7 +168,7 @@ class GridPoints:
        shape=(ir-grid points, 3)
     weights: ndarray
        Geometric q-point weights. Its sum is the number of grid points.
-       dtype='int_'
+       dtype='int64'
        shape=(ir-grid points,)
     grid_address: ndarray
        Addresses of all grid points represented by integers.
@@ -174,10 +176,10 @@ class GridPoints:
        shape=(prod(mesh_numbers), 3)
     ir_grid_points: ndarray
         Indices of irreducible grid points in grid_address.
-        dtype='int_', shape=(ir-grid points,)
+        dtype='int64', shape=(ir-grid points,)
     grid_mapping_table: ndarray
         Index mapping table from all grid points to ir-grid points.
-        dtype='int_', shape=(prod(mesh_numbers),)
+        dtype='int64', shape=(prod(mesh_numbers),)
 
     """
 
@@ -204,7 +206,7 @@ class GridPoints:
         ----------
         mesh_numbers: array_like
             Mesh numbers along a, b, c axes.
-            dtype='int_'
+            dtype='int64'
             shape=(3, )
         reciprocal_lattice: array_like
             Basis vectors in reciprocal space. a*, b*, c* are given in column
@@ -228,7 +230,7 @@ class GridPoints:
         rotations: array_like, default None (only unitary operation)
             Rotation matrices in direct space. For each rotation matrix R,
             a point in crystallographic coordinates, x, is sent as x' = Rx.
-            dtype='int_'
+            dtype='int64'
             shape=(rotations, 3, 3)
         is_mesh_symmetry: bool, optional, default True
             Wheather symmetry search is done or not.
@@ -390,11 +392,11 @@ class GridPoints:
         return np.extract(lattice_equiv, mesh_equiv).all()
 
     def _fit_qpoints_in_BZ(self):
-        qpoint_set_in_BZ = get_qpoints_in_Brillouin_zone(
+        qpolongset_in_BZ = get_qpoints_in_Brillouin_zone(
             self._rec_lat, self._ir_qpoints
         )
         qpoints_in_BZ = np.array(
-            [q_set[0] for q_set in qpoint_set_in_BZ], dtype="double", order="C"
+            [q_set[0] for q_set in qpolongset_in_BZ], dtype="double", order="C"
         )
         self._ir_qpoints = qpoints_in_BZ
 
@@ -406,14 +408,14 @@ class GridPoints:
             is_time_reversal=is_time_reversal,
             is_dense=True,
         )
-        # uintp to int_
-        grid_mapping_table = np.array(grid_mapping_table, dtype="int_")
+        # uintp to long
+        grid_mapping_table = np.array(grid_mapping_table, dtype="int64")
 
-        # Currently 'intc', but will be 'int_' in next major version.
+        # Currently 'intc', but will be 'int64' in next major version.
         if int(__version__.split(".")[0]) < 3:
             dtype = "intc"
         else:
-            dtype = "int_"
+            dtype = "int64"
 
         if self._fit_in_BZ:
             grid_address, _ = relocate_BZ_grid_address(
@@ -474,14 +476,14 @@ class GeneralizedRegularGridPoints:
     ----------
     grid_address : ndarray
         Grid addresses in integers.
-        shape=(num_grid_points, 3), dtype='int_', order='C'
+        shape=(num_grid_points, 3), dtype='int64', order='C'
     qpoints : ndarray
         q-points with respect to basis vectors of input or standardized
         primitive cell.
         shape=(num_grid_points, 3), dtype='double', order='C'
     grid_matrix : ndarray
         Grid generating matrix.
-        shape=(3,3), dtype='int_', order='C'
+        shape=(3,3), dtype='int64', order='C'
     matrix_to_primitive : ndarray or None
         None when ``suggest`` is False. Otherwise, transformation matrix from
         input cell to the suggested primitive cell.
@@ -533,7 +535,7 @@ class GeneralizedRegularGridPoints:
         self._generate_grid_points()
         self._generate_q_points()
         self._reciprocal_operations = get_reciprocal_operations(
-            self._sym_dataset["rotations"],
+            self._sym_dataset.rotations,
             self._transformation_matrix,
             self._snf.D,
             self._snf.Q,
@@ -577,7 +579,9 @@ class GeneralizedRegularGridPoints:
 
     def _prepare(self, cell, length, symprec):
         """Define grid generating matrix and run the SNF."""
-        self._sym_dataset = get_symmetry_dataset(cell.totuple(), symprec=symprec)
+        self._sym_dataset = get_dot_access_dataset(
+            get_symmetry_dataset(cell.totuple(), symprec=symprec)
+        )
         if self._suggest:
             self._set_grid_matrix_by_std_primitive_cell(cell, length)
         else:
@@ -586,22 +590,22 @@ class GeneralizedRegularGridPoints:
         self._snf.run()
 
     def _set_grid_matrix_by_std_primitive_cell(self, cell, length):
-        """Grid generating matrix based on standeardized primitive cell."""
-        tmat = self._sym_dataset["transformation_matrix"]
-        centring = self._sym_dataset["international"][0]
+        """Grid generating matrix based on standardized primitive cell."""
+        tmat = self._sym_dataset.transformation_matrix
+        centring = self._sym_dataset.international[0]
         pmat = get_primitive_matrix_by_centring(centring)
         conv_lat = np.dot(np.linalg.inv(tmat).T, cell.cell)
         num_cells = np.prod(length2mesh(length, conv_lat))
         self._mesh_numbers = estimate_supercell_matrix(
             self._sym_dataset,
-            max_num_atoms=num_cells * len(self._sym_dataset["std_types"]),
+            max_num_atoms=num_cells * len(self._sym_dataset.std_types),
         )
         inv_pmat = np.linalg.inv(pmat)
         inv_pmat_int = np.rint(inv_pmat).astype(int)
         assert (np.abs(inv_pmat - inv_pmat_int) < 1e-5).all()
         # transpose in reciprocal space
         self._grid_matrix = np.array(
-            (inv_pmat_int * self._mesh_numbers).T, dtype="int_", order="C"
+            (inv_pmat_int * self._mesh_numbers).T, dtype="int64", order="C"
         )
         # From input lattice to the primitive lattice in real space
         self._transformation_matrix = np.array(
@@ -610,7 +614,7 @@ class GeneralizedRegularGridPoints:
 
     def _set_grid_matrix_by_input_cell(self, input_cell, length):
         """Grid generating matrix based on input cell."""
-        pointgroup = get_pointgroup(self._sym_dataset["rotations"])
+        pointgroup = get_pointgroup(self._sym_dataset.rotations)
         # tmat: From input lattice to point group preserving lattice
         tmat = pointgroup[2]
         lattice = np.dot(input_cell.cell.T, tmat).T
@@ -620,7 +624,7 @@ class GeneralizedRegularGridPoints:
         )
         # transpose in reciprocal space
         self._grid_matrix = np.array(
-            np.multiply(tmat, self._mesh_numbers).T, dtype="int_", order="C"
+            np.multiply(tmat, self._mesh_numbers).T, dtype="int64", order="C"
         )
         self._transformation_matrix = np.eye(3, dtype="double", order="C")
 
@@ -633,7 +637,7 @@ class GeneralizedRegularGridPoints:
             # z runs fastest.
             x, y, z = np.meshgrid(range(d[0]), range(d[1]), range(d[2]), indexing="ij")
         self._grid_address = np.array(
-            np.c_[x.ravel(), y.ravel(), z.ravel()], dtype="int_", order="C"
+            np.c_[x.ravel(), y.ravel(), z.ravel()], dtype="int64", order="C"
         )
 
     def _generate_q_points(self):
@@ -656,7 +660,7 @@ def get_reciprocal_operations(
     ----------
     rotations : ndarray
         Rotation matrices in real space. x' = Rx.
-        shape=(rotations, 3, 3), dtype='int_'
+        shape=(rotations, 3, 3), dtype='int64'
     transformation_matrxi : array_like
         Transformation matrix of basis vectors in real space. Using this
         rotation matrices are transformed.
@@ -677,7 +681,7 @@ def get_reciprocal_operations(
 
         g' = (R_Q g) % diagonal(D)
 
-        shape=(rotations, 3, 3), dtype='int_', order='C'
+        shape=(rotations, 3, 3), dtype='int64', order='C'
 
     """
     unique_rots = []
@@ -702,4 +706,4 @@ def get_reciprocal_operations(
         assert abs(determinant(_r_int)) == 1
         rec_ops_Q.append(_r_int)
 
-    return np.array(rec_ops_Q, dtype="int_", order="C")
+    return np.array(rec_ops_Q, dtype="int64", order="C")
