@@ -2,8 +2,8 @@
 
 from __future__ import annotations
 
+import pathlib
 from collections.abc import Callable
-from pathlib import Path
 
 import numpy as np
 import pytest
@@ -12,7 +12,7 @@ import phonopy
 from phonopy import Phonopy
 from phonopy.structure.atoms import PhonopyAtoms
 
-cwd = Path(__file__).parent
+cwd = pathlib.Path(__file__).parent
 
 
 @pytest.fixture(scope="session")
@@ -161,6 +161,7 @@ def ph_nacl_rd_symfc() -> Phonopy:
 
     """
     pytest.importorskip("symfc")
+    pytest.importorskip("spglib", minversion="2.5")
 
     yaml_filename = cwd / "phonopy_params_NaCl-rd.yaml.xz"
     return phonopy.load(
@@ -238,6 +239,13 @@ def ph_srtio3() -> Phonopy:
     )
 
 
+@pytest.fixture(scope="session")
+def ph_kcl() -> Phonopy:
+    """Return Phonopy class instance of KCl for mlpsscha_KCl-120.pmlp."""
+    yaml_filename = cwd / "phonopy_KCl.yaml"
+    return phonopy.load(yaml_filename, produce_fc=False, log_level=1)
+
+
 @pytest.fixture(scope="session")
 def ph_nacl_gruneisen() -> tuple[Phonopy, Phonopy, Phonopy]:
     """Return Phonopy class instances of NaCl 2x2x2 at three volumes."""
@@ -275,6 +283,50 @@ def convcell_sio2() -> PhonopyAtoms:
     return PhonopyAtoms(cell=lattice, scaled_positions=points, symbols=symbols)
 
 
+@pytest.fixture(scope="session")
+def convcell_al2o3() -> PhonopyAtoms:
+    """Return PhonopyAtoms class instance of rutile Al2O3."""
+    symbols = ["Al"] * 12 + ["O"] * 18
+    lattice = [
+        [4.7742263452989944, 0.0000000000000000, 0.0000000000000000],
+        [-2.3871131726494972, 4.1346012984458653, 0.0000000000000000],
+        [-0.0000000000000000, 0.0000000000000000, 13.0113593913272219],
+    ]
+    points = [
+        [0.3333333333333357, 0.6666666666666643, 0.0187603745624614],
+        [0.3333333333333357, 0.6666666666666643, 0.3145729587708743],
+        [0.0000000000000000, 0.0000000000000000, 0.1479062921042101],
+        [0.6666666666666643, 0.3333333333333357, 0.1854270412291256],
+        [0.0000000000000000, 0.0000000000000000, 0.3520937078957900],
+        [0.0000000000000000, 0.0000000000000000, 0.6479062921042100],
+        [0.6666666666666643, 0.3333333333333357, 0.4812396254375386],
+        [0.3333333333333357, 0.6666666666666643, 0.5187603745624614],
+        [0.6666666666666643, 0.3333333333333357, 0.6854270412291257],
+        [0.6666666666666643, 0.3333333333333357, 0.9812396254375386],
+        [0.3333333333333357, 0.6666666666666643, 0.8145729587708743],
+        [0.0000000000000000, 0.0000000000000000, 0.8520937078957900],
+        [0.3058086537880128, 0.0000000000000000, 0.2500000000000000],
+        [0.3608580128786515, 0.3333333333333357, 0.0833333333333357],
+        [0.0000000000000000, 0.3058086537880128, 0.2500000000000000],
+        [0.6666666666666643, 0.0275246795453229, 0.0833333333333357],
+        [0.6941913462119872, 0.6941913462119872, 0.2500000000000000],
+        [0.9724753204546771, 0.6391419871213485, 0.0833333333333357],
+        [0.9724753204546771, 0.3333333333333357, 0.5833333333333357],
+        [0.0275246795453229, 0.6666666666666643, 0.4166666666666643],
+        [0.6666666666666643, 0.6391419871213485, 0.5833333333333357],
+        [0.3333333333333357, 0.3608580128786515, 0.4166666666666643],
+        [0.3608580128786515, 0.0275246795453229, 0.5833333333333357],
+        [0.6391419871213485, 0.9724753204546771, 0.4166666666666643],
+        [0.6391419871213485, 0.6666666666666643, 0.9166666666666643],
+        [0.6941913462119872, 0.0000000000000000, 0.7500000000000000],
+        [0.3333333333333357, 0.9724753204546771, 0.9166666666666643],
+        [0.0000000000000000, 0.6941913462119872, 0.7500000000000000],
+        [0.0275246795453229, 0.3608580128786515, 0.9166666666666643],
+        [0.3058086537880128, 0.3058086537880128, 0.7500000000000000],
+    ]
+    return PhonopyAtoms(cell=lattice, scaled_positions=points, symbols=symbols)
+
+
 @pytest.fixture(scope="session")
 def primcell_si() -> PhonopyAtoms:
     """Return PhonopyAtoms class instance of primitive cell of Si."""
