@@ -620,6 +620,24 @@ chars_Pbar6m2 = """ 2.  0. -1.  0. -1.  0.  2.  0. -1.  0. -1.  0.  0.  0.  0.
  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.
  2.  0. -1.  0. -1.  0.  2.  0. -1.  0. -1.  0. -0.  0. -0.  0.  0.  0. -0.  0. -0.  0.  0.  0."""
 
+chars_Pbar62m = """ 3.  0. -2.  0. -0.  0.  1.  0. -0.  0. -2.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.
+ 2.  0. -1.  0. -1.  0.  2.  0. -1.  0. -1.  0. -0.  0.  0.  0.  0.  0. -0.  0.  0.  0.  0.  0.
+ 2.  0.  1.  0. -1.  0. -2.  0. -1.  0.  1.  0.  0.  0. -0.  0. -0.  0. -0.  0.  0.  0.  0.  0.
+ 1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.
+ 2.  0. -1.  0. -1.  0.  2.  0. -1.  0. -1.  0. -0.  0.  0.  0.  0.  0. -0.  0.  0.  0.  0.  0.
+ 1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0. -1.  0. -1.  0. -1.  0. -1.  0. -1.  0. -1.  0.
+ 1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0.
+ 2.  0. -1.  0. -1.  0.  2.  0. -1.  0. -1.  0.  0.  0.  0.  0. -0.  0.  0.  0.  0.  0. -0.  0.
+ 1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.
+ 2.  0. -1.  0. -1.  0.  2.  0. -1.  0. -1.  0.  0.  0. -0.  0.  0.  0.  0.  0. -0.  0.  0.  0.
+ 1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.
+ 2.  0. -1.  0. -1.  0.  2.  0. -1.  0. -1.  0.  0.  0.  0.  0.  0.  0.  0.  0.  0.  0.  0.  0.
+ 2.  0.  1.  0. -1.  0. -2.  0. -1.  0.  1.  0. -0.  0.  0.  0.  0.  0.  0.  0.  0.  0. -0.  0.
+ 1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0. -1.  0. -1.  0. -1.  0. -1.  0. -1.  0. -1.  0.
+ 1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.
+ 2.  0. -1.  0. -1.  0.  2.  0. -1.  0. -1.  0. -0.  0.  0.  0.  0.  0. -0.  0.  0.  0.  0.  0.
+ 1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0.  1.  0. -1.  0."""
+
 chars_P2_13 = """ 3.  0. -1.  0. -1.  0. -1.  0. -0.  0. -0.  0. -0.  0.  0.  0. -0.  0.  0.  0. -0.  0. -0.  0.
  2.  0.  2.  0.  2.  0.  2.  0. -1.  0. -1.  0. -1.  0. -1.  0. -1.  0. -1.  0. -1.  0. -1.  0.
  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.  1.  0.
@@ -1013,6 +1031,25 @@ def test_pt26_Pbar6m2():
     _check_char_sum(phonon, qpoints)
 
 
+def test_pt26_Pbar62m():
+    """Test of pt26_Pbar62m."""
+    data = _load_data(chars_Pbar62m)
+    phonon = _get_phonon("P-62m", [1, 1, 2], np.eye(3))
+    phonon.set_irreps([0, 0, 0])
+    chars = phonon.irreps.characters
+    _show_chars(chars)
+    np.testing.assert_allclose(chars, data, atol=1e-5)
+    qpoints = [
+        [0, 0, 0.5],
+        [1.0 / 3, 1.0 / 3, 0],
+        [1.0 / 3, 1.0 / 3, 0.5],
+    ]  # A, K, H
+    assert set(phonon.irreps.rotation_symbols) == set(
+        ["E", "S3", "C3", "sgh", "C3", "S3", "C'2", "sgv", "C'2", "sgv", "C'2", "sgv"]
+    )
+    _check_char_sum(phonon, qpoints)
+
+
 def test_pt28_P2_13():
     """Test of pt28_P2_13."""
     data = _load_data(chars_P2_13)
@@ -1187,7 +1224,7 @@ def _load_data(data_str):
 
 
 def _check_char_sum(phonon: Phonopy, qpoints: list):
-    print("space-group number:", phonon.symmetry.dataset["number"])
+    print("space-group number:", phonon.symmetry.dataset.number)
 
     for q in qpoints:
         phonon.set_irreps(q)
