@@ -15,7 +15,7 @@ def test_MLPSSCHA(ph_kcl: Phonopy):
     """Test MLPSSCHA class."""
     pytest.importorskip("pypolymlp")
     pytest.importorskip("symfc")
-    mlp = PhonopyMLP().load(cwd / ".." / "mlpsscha_KCl-120.pmlp")
+    mlp = PhonopyMLP().load(cwd / ".." / "polymlp_KCL-120.yaml")
     sscha = MLPSSCHA(
         ph_kcl,
         mlp,
